@@ -800,7 +800,7 @@ void Font::put_paragraph(int x1, int y1, int x2, int y2, const char *textPtr,
 				line_count++;
 			}
 
-			if( *textPtr == NULL )     // all paragraph has been printed
+			if( *textPtr == '\0' )     // all paragraph has been printed
 				break;
 
 			wordPtr = textPtr;
@@ -810,7 +810,7 @@ void Font::put_paragraph(int x1, int y1, int x2, int y2, const char *textPtr,
 
 		//------------ process spacing -------------//
 
-		if( *textPtr == ' ' || *textPtr == '\n' || *textPtr == NULL )    // not space
+		if( *textPtr == ' ' || *textPtr == '\n' || *textPtr == '\0' )    // not space
 			newWord = 1;
 		else
 		{
@@ -996,7 +996,7 @@ void Font::put_field(int x1, int y1, const char* desStr, int x2, int value, int
 	vga_util.d3_panel_up( x1, y1, x2, y1+font_height+3 );
 
 	put( x1+2, y1+2, desStr);
-	put( x2+4, y1+2, m.format(value,format) );
+	put( x2+4, y1+2, misc.format(value,format) );
 }
 //--------- End of function Font::put_field ---------//
 
@@ -1021,7 +1021,7 @@ void Font::update_field(int x1, int y1, int value, int format, int x2)
 	if( x2<0 )
       x2 = x1+80;
 
-   put( x1+4, y1+2, m.format(value,format), 1, x2 );
+   put( x1+4, y1+2, misc.format(value,format), 1, x2 );
 }
 //--------- End of function Font::update_field ---------//
 
@@ -1056,11 +1056,11 @@ void Font::field(int xDes, int y1, const char* desStr, int xValue, int value,
 		vga_util.d3_panel_up( xDes, y1, xValue, y1+font_height+3 );
 
 		put( xDes+2  , y1+2, desStr);
-		x2 = put( xValue+4, y1+2, m.format(value,format) );
+		x2 = put( xValue+4, y1+2, misc.format(value,format) );
 	}
 	else
 	{
-		x2 = put( xValue+4, y1+2, m.format(value,format), 1, xEnd );
+		x2 = put( xValue+4, y1+2, misc.format(value,format), 1, xEnd );
 	}
 
 	if( helpCode )
@@ -1090,7 +1090,7 @@ void Font::put_field(int x1, int y1, const char* desStr, int x2, double value, i
 	vga_util.d3_panel_up( x1, y1, x2, y1+font_height+3 );
 
 	put( x1+2, y1+2, desStr);
-	put( x2+4, y1+2, m.format(value,format) );
+	put( x2+4, y1+2, misc.format(value,format) );
 }
 //--------- End of function Font::put_field ---------//
 
@@ -1115,7 +1115,7 @@ void Font::update_field(int x1, int y1, double value, int format, int x2)
 	if( x2<0 )
       x2 = x1+80;
 
-   put( x1+4, y1+2, m.format(value,format), 1, x2 );
+   put( x1+4, y1+2, misc.format(value,format), 1, x2 );
 }
 //--------- End of function Font::update_field ---------//
 
@@ -1150,11 +1150,11 @@ void Font::field(int xDes, int y1, const char* desStr, int xValue, double value,
 		vga_util.d3_panel_up( xDes, y1, xValue, y1+font_height+3 );
 
       put( xDes+2  , y1+2, desStr);
-      x2 = put( xValue+4, y1+2, m.format(value,format) );
+      x2 = put( xValue+4, y1+2, misc.format(value,format) );
    }
    else
    {
-		x2 = put( xValue+4, y1+2, m.format(value,format), 1, xEnd );
+		x2 = put( xValue+4, y1+2, misc.format(value,format), 1, xEnd );
 	}
 
 	if( helpCode )
@@ -1263,7 +1263,7 @@ int Font::disp(int x1, int y1, int value, int format, int x2)
 	if( x2<0 )
       x2 = x1+80;
 
-   int lastX = put( x1, y1, m.format(value,format), 1, x2 );
+   int lastX = put( x1, y1, misc.format(value,format), 1, x2 );
 
    return lastX;
 }
@@ -1291,7 +1291,7 @@ int Font::disp(int x1, int y1, double value, int format, int x2)
 	if( x2<0 )
       x2 = x1+80;
 
-   int lastX = put( x1, y1, m.format(value,format), 1, x2 );
+   int lastX = put( x1, y1, misc.format(value,format), 1, x2 );
 
    return lastX;
 }
