@@ -249,24 +249,9 @@ static int select_option()
 		#else
 			#define Y_SHIFT 0
 		#endif
-#ifdef AMPLUS
 		terrainGroup[i].create(168+i*BASIC_OPTION_X_SPACE, offsetY+258+Y_SHIFT, 
 			168+(i+1)*BASIC_OPTION_X_SPACE-1, offsetY+258+Y_SHIFT+BASIC_OPTION_HEIGHT-1,
 			disp_virtual_button, ButtonCustomPara(&terrainGroup, i+1), 0, 0);
-#else
-		// BUGHERE : terrain_set 2 is disable, exchange the position of button 1 and 2
-		int k = i;
-		switch(i)
-		{
-		case 1: k = 2; break;
-		case 2: k = 1; break;
-		}
-		terrainGroup[i].create(205+k*BASIC_OPTION_X_SPACE, offsetY+258+Y_SHIFT, 
-			205+(k+1)*BASIC_OPTION_X_SPACE-1, offsetY+258+Y_SHIFT+BASIC_OPTION_HEIGHT-1,
-			disp_virtual_button, ButtonCustomPara(&terrainGroup, i+1), 0, 0);
-		if( i == 1 )
-			terrainGroup[i].enable_flag = 0;
-#endif
 		#undef Y_SHIFT
 	}
 
@@ -567,7 +552,7 @@ static int select_option()
 						#define Y_SHIFT 0
 					#endif
 					font_san.center_put(564, offsetY+154+Y_SHIFT, 564+25, offsetY+154+Y_SHIFT+21,
-						m.format(tempConfig.ai_nation_count), 1);
+						misc.format(tempConfig.ai_nation_count), 1);
 					aiNationInc.paint();
 					aiNationDec.paint();
 					#undef Y_SHIFT
@@ -621,7 +606,7 @@ static int select_option()
 				if( refreshFlag & SGOPTION_RAW )
 				{
 					font_san.center_put(337, offsetY+105, 337+25, offsetY+105+21,
-						m.format(tempConfig.start_up_raw_site), 1);
+						misc.format(tempConfig.start_up_raw_site), 1);
 					rawSiteInc.paint();
 					rawSiteDec.paint();
 				}
@@ -660,7 +645,7 @@ static int select_option()
 				{
 					enoughPeopleButton.paint(tempConfig.goal_population_flag);
 					font_san.center_put( 456, offsetY+211, 456+67, offsetY+211+21,
-						m.format(tempConfig.goal_population) ,1);
+						misc.format(tempConfig.goal_population) ,1);
 					peopleInc.paint();
 					peopleDec.paint();
 				}
@@ -668,7 +653,7 @@ static int select_option()
 				{
 					enoughIncomeButton.paint(tempConfig.goal_economic_score_flag);
 					font_san.center_put( 456, offsetY+243, 456+67, offsetY+243+21,
-						m.format(tempConfig.goal_economic_score), 1);
+						misc.format(tempConfig.goal_economic_score), 1);
 					incomeInc.paint();
 					incomeDec.paint();
 				}
@@ -676,7 +661,7 @@ static int select_option()
 				{
 					enoughScoreButton.paint(tempConfig.goal_total_score_flag);
 					font_san.center_put( 456, offsetY+275, 456+67, offsetY+275+21,
-						m.format(tempConfig.goal_total_score), 1);
+						misc.format(tempConfig.goal_total_score), 1);
 					scoreInc.paint();
 					scoreDec.paint();
 				}
@@ -684,7 +669,7 @@ static int select_option()
 				{
 					timeLimitButton.paint(tempConfig.goal_year_limit_flag);
 					font_san.center_put( 456, offsetY+307, 456+33, offsetY+307+21,
-						m.format(tempConfig.goal_year_limit), 1);
+						misc.format(tempConfig.goal_year_limit), 1);
 					yearInc.paint();
 					yearDec.paint();
 				}
@@ -694,7 +679,7 @@ static int select_option()
 			if( refreshFlag & SGOPTION_DIFFICULTY )
 			{
 				font_san.center_put( 718, offsetY+74, 780, offsetY+108,
-					m.format(tempConfig.single_player_difficulty()), 1 );
+					misc.format(tempConfig.single_player_difficulty()), 1 );
 			}
 
 			// -------- repaint button -------//
@@ -1064,12 +1049,6 @@ static int select_option()
 		info.init_random_seed( atol(mapIdStr) );
 		tempConfig.difficulty_rating = tempConfig.single_player_difficulty();
 
-		// BUGHERE : terrain_set 2 is not available
-#ifndef AMPLUS
-		if( tempConfig.terrain_set == 2 )
-      	tempConfig.terrain_set = 1;
-#endif
-
 		config = tempConfig;
 	}
 
