@@ -109,7 +109,7 @@ GameFileArray::GameFileArray() : DynArray( sizeof(GameFile), 10 )
 		demo_format = 1;
 	#endif
 
-	last_file_name[0] = NULL;
+	last_file_name[0] = '\0';
 	has_read_hall_of_fame = 0;
 
 	memset( hall_fame_array, 0, sizeof(HallFame)*HALL_FAME_NUM );
@@ -788,7 +788,7 @@ void GameFileArray::del_game()
 
 	//---------------------------------------------------//
 
-	if (!m.path_cat(full_path, sys.dir_config, game_file_array[recNo]->file_name, MAX_PATH))
+	if (!misc.path_cat(full_path, sys.dir_config, game_file_array[recNo]->file_name, MAX_PATH))
 	{
 		ERR("Path to the saved game too long.\n");
 		return;
@@ -812,7 +812,7 @@ int GameFileArray::write_hall_of_fame()
 	int  rc;
 	File file;
 
-	if (!m.path_cat(full_path, sys.dir_config, HALL_OF_FAME_FILE_NAME, MAX_PATH))
+	if (!misc.path_cat(full_path, sys.dir_config, HALL_OF_FAME_FILE_NAME, MAX_PATH))
 	{
 		ERR("Path to the hall of fame too long.\n");
 		return 0;
@@ -848,13 +848,13 @@ int GameFileArray::read_hall_of_fame()
 	int  rc;
 	File file;
 
-	if (!m.path_cat(full_path, sys.dir_config, HALL_OF_FAME_FILE_NAME, MAX_PATH))
+	if (!misc.path_cat(full_path, sys.dir_config, HALL_OF_FAME_FILE_NAME, MAX_PATH))
 	{
 		ERR("Path to the hall of fame too long.\n");
 		return 0;
 	}
 
-	if( !m.is_file_exist(full_path) )
+	if( !misc.is_file_exist(full_path) )
 		return 0;
 
 	rc = file.file_open(full_path, 0, 1);   // 0=don't handle error itself
@@ -891,7 +891,7 @@ void GameFileArray::load_all_game_header(const char *extStr)
 	GameFile  gameFile;
 	File      file;
 
-	if (!m.path_cat(full_path, sys.dir_config, extStr, MAX_PATH))
+	if (!misc.path_cat(full_path, sys.dir_config, extStr, MAX_PATH))
 	{
 		ERR("Path to the config directory too long.\n");
 		return;
@@ -904,7 +904,7 @@ void GameFileArray::load_all_game_header(const char *extStr)
 
 	for( i=1 ; i<=gameDir.size() ; i++ )
 	{
-		if (!m.path_cat(full_path, sys.dir_config, gameDir[i]->name, MAX_PATH))
+		if (!misc.path_cat(full_path, sys.dir_config, gameDir[i]->name, MAX_PATH))
 		{
 			ERR("Path to the saved game too long.\n");
 			continue;
@@ -965,14 +965,14 @@ GameFile* GameFileArray::operator[](int recNo)
 static void key_search()
 {
 	int i;
-	int searchKey = m.upper(mouse.key_code);
+	int searchKey = misc.upper(mouse.key_code);
 
 	if( searchKey < '0' || searchKey > 'Z' )
 		return;
 
 	for( i=1 ; i<=game_file_array.size() ; i++ )
 	{
-		if( m.upper(game_file_array[i]->file_name[0]) >= searchKey )
+		if( misc.upper(game_file_array[i]->file_name[0]) >= searchKey )
 		{
 			browse_recno = i+(action_mode==1);
 			return;
