@@ -940,7 +940,7 @@ void NewsArray::chat_msg(int fromNationRecno, char* chatStr)
 		chatInfo->from_nation_recno = fromNationRecno;
 
 		strncpy( chatInfo->chat_str, chatStr, CHAT_STR_LEN );
-		chatInfo->chat_str[CHAT_STR_LEN] = NULL;
+		chatInfo->chat_str[CHAT_STR_LEN] = '\0';
 	}
 
 	//----------------------------------------------//
@@ -1192,3 +1192,4 @@ int News::is_loc_valid()
 }
 //------- End of function News::is_loc_valid -------//
 
+
