@@ -221,7 +221,7 @@ void News::migrate()
 	if( short_para4 == 1 )
 		str = "Un ";
 	else
-		str = m.format(short_para4);
+		str = misc.format(short_para4);
 
 	str += " ";
 
@@ -786,7 +786,7 @@ void News::monster_gold_acquired()
 	//----------------------------------------------//
 
 	str  = "Vous vous tes empar d'un trsor Fryhtan d'une valeur de";
-	str += m.format(short_para1,2);
+	str += misc.format(short_para1,2);
 	str += ".";
 }
 //------- End of function News::monster_gold_acquired -----//
@@ -1171,7 +1171,7 @@ void News::tech_researched()
 	if( tech_res[short_para1]->max_tech_level > 1 )		// if the tech has more than one level
 	{
 		str += " Version ";
-		str += m.roman_number(short_para2);
+		str += misc.roman_number(short_para2);
 	}
 
 	str += ".";
@@ -1405,7 +1405,7 @@ void News::weapon_ship_worn_out()
 	if( short_para2 )
 	{
 		str += " ";
-		str += m.roman_number(short_para2);
+		str += misc.roman_number(short_para2);
 	}
 
 	str += " est inutilisable en raison du manque de fonds pour la maintenance.";
