@@ -414,7 +414,7 @@ void TalkMsg::request_buy_food()
 	{
 		str =  from_nation_name();
 		str += " offers ";
-		str += m.format(talk_para2,2);
+		str += misc.format(talk_para2,2);
 		str += " for 10 units of food.";
 
 		return;
@@ -543,7 +543,7 @@ void TalkMsg::give_tribute(const char* tributeStr)
 			str  = "You offer ";
 			str += to_nation_name();
 			str += " ";
-			str += m.format(talk_para1, 2);
+			str += misc.format(talk_para1, 2);
 			str += " in ";
 			str += tributeStr;
 			str += ".";
@@ -552,7 +552,7 @@ void TalkMsg::give_tribute(const char* tributeStr)
 		{
 			str  = from_nation_name();
 			str += " offers you ";
-			str += m.format(talk_para1, 2);
+			str += misc.format(talk_para1, 2);
 			str += " in ";
 			str += tributeStr;
 			str += ".";
@@ -571,7 +571,7 @@ void TalkMsg::give_tribute(const char* tributeStr)
 
 			str += tributeStr;
 			str += " of ";
-			str += m.format(talk_para1, 2);
+			str += misc.format(talk_para1, 2);
 			str += ".";
 		}
 		else
@@ -581,7 +581,7 @@ void TalkMsg::give_tribute(const char* tributeStr)
 			else
 				str = "You reject the ";
 
-			str += m.format(talk_para1, 2);
+			str += misc.format(talk_para1, 2);
 			str += " in ";
 			str += tributeStr;
 			str += " from ";
@@ -635,7 +635,7 @@ void TalkMsg::demand_tribute(int isAid)
 			else
 				str = "You demand ";
 
-			str += m.format(talk_para1,2);
+			str += misc.format(talk_para1,2);
 			str += " in ";
 			str += aidStr;
 			str += " from ";
@@ -651,7 +651,7 @@ void TalkMsg::demand_tribute(int isAid)
 			else
 				str += " demands ";
 
-			str += m.format(talk_para1,2);
+			str += misc.format(talk_para1,2);
 			str += " in ";
 			str += aidStr;
 			str += " from you.";
@@ -689,7 +689,7 @@ void TalkMsg::demand_tribute(int isAid)
 			str += " ";
 		}
 
-		str += m.format(talk_para1,2);
+		str += misc.format(talk_para1,2);
 		str += " in ";
 		str += aidStr;
 		str += ".";
@@ -731,7 +731,7 @@ void TalkMsg::give_tech()
 			if( talk_para2 )		// Ships do not have different versions 
 			{
 				str += " ";
-				str += m.roman_number(talk_para2);
+				str += misc.roman_number(talk_para2);
 			}
 
 			str += " technology to ";
@@ -747,7 +747,7 @@ void TalkMsg::give_tech()
 			if( talk_para2 )		// Ships do not have different versions
 			{
 				str += " ";
-				str += m.roman_number(talk_para2);
+				str += misc.roman_number(talk_para2);
 			}
 
 			str += " technology to you.";
@@ -769,7 +769,7 @@ void TalkMsg::give_tech()
 			if( talk_para2 )		// Ships do not have different versions
 			{
 				str += " ";
-				str += m.roman_number(talk_para2);
+				str += misc.roman_number(talk_para2);
 			}
 
 			str += " technology.";
@@ -786,7 +786,7 @@ void TalkMsg::give_tech()
 			if( talk_para2 )		// Ships do not have different versions
 			{
 				str += " ";
-				str += m.roman_number(talk_para2);
+				str += misc.roman_number(talk_para2);
 			}
 
 			str += " technology from ";
