@@ -60,7 +60,7 @@ void Town::process_ai()
 	{
 		LOG_MSG(" update_base_town_status");
 		update_base_town_status();
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 
 	//------ think about granting villagers ---//
@@ -69,7 +69,7 @@ void Town::process_ai()
 	{
 		LOG_MSG(" think_reward");
 		think_reward();
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 
 	//----- if this town should migrate now -----//
@@ -80,7 +80,7 @@ void Town::process_ai()
 		{
 			LOG_MSG(" think_ai_migrate");
 			think_ai_migrate();
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 		}
 
 		return;		// don't do anything else if the town is about to migrate
@@ -94,10 +94,10 @@ void Town::process_ai()
 		LOG_MSG(" think_build_camp");
 		if( think_build_camp() )
 		{
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 			return;
 		}
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 
 	//----- the following are base town only functions ----//
@@ -111,7 +111,7 @@ void Town::process_ai()
 	{
 		LOG_MSG("think_collect_tax");
 		think_collect_tax();
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 
 	//---- think about scouting in an unexplored map ----//
@@ -127,10 +127,10 @@ void Town::process_ai()
 	{
 		LOG_MSG("think_split_town");
 		think_split_town();
-		LOG_MSG(m.get_random_seed() );
+		LOG_MSG(misc.get_random_seed() );
 		LOG_MSG("think_move_between_town");
 		think_move_between_town();
-		LOG_MSG(m.get_random_seed() );
+		LOG_MSG(misc.get_random_seed() );
 	}
 
 	//---- think about attacking firms/units nearby ---//
@@ -140,18 +140,18 @@ void Town::process_ai()
 		LOG_MSG(" think_attack_nearby_enemy");
 		if( think_attack_nearby_enemy() )
 		{
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 			return;
 		}
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 
 		LOG_MSG(" think_attack_linked_enemy");
 		if( think_attack_linked_enemy() )
 		{
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 			return;
 		}
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 
 	//---- think about capturing linked enemy firms ----//
@@ -160,7 +160,7 @@ void Town::process_ai()
 	{
 		LOG_MSG(" think_capture_linked_firm");
 		think_capture_linked_firm();
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 
 	//---- think about capturing enemy towns ----//
@@ -169,7 +169,7 @@ void Town::process_ai()
 	{
 		LOG_MSG(" think_capture_enemy_town");
 		think_capture_enemy_town();
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 
 	//---- think about using spies on enemies ----//
@@ -179,7 +179,7 @@ void Town::process_ai()
 		LOG_MSG(" think_spying_town");
 		if( think_spying_town() )
 		{
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 			return;
 		}
 	}
@@ -191,7 +191,7 @@ void Town::process_ai()
 		LOG_MSG(" think_counter_spy");
 		if( think_counter_spy() )
 		{
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 			return;
 		}
 	}
@@ -204,10 +204,10 @@ void Town::process_ai()
 		LOG_MSG(" think_build_market");
 		if( think_build_market() )
 		{
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 			return;
 		}
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 
 		//--- the following functions will only be called when the nation has at least a mine ---//
 
@@ -225,33 +225,33 @@ void Town::process_ai()
 			LOG_MSG(" think_build_research");
 			if( think_build_research() )
 			{
-				LOG_MSG(m.get_random_seed());
+				LOG_MSG(misc.get_random_seed());
 				return;
 			}
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 
 			LOG_MSG(" think_build_war_factory");
 			if( think_build_war_factory() )
 			{
-				LOG_MSG(m.get_random_seed());
+				LOG_MSG(misc.get_random_seed());
 				return;
 			}
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 
 			LOG_MSG(" think_build_base");
 			if( think_build_base() )
 			{
-				LOG_MSG(m.get_random_seed());
+				LOG_MSG(misc.get_random_seed());
 				return;
 			}
-			LOG_MSG(m.get_random_seed());
+			LOG_MSG(misc.get_random_seed());
 		}
 
 		//-------- think build inn ---------//
 
 		LOG_MSG(" think_build_inn");
 		think_build_inn();
-		LOG_MSG(m.get_random_seed());
+		LOG_MSG(misc.get_random_seed());
 	}
 }
 //--------- End of function Town::process_ai ----------//
@@ -1252,7 +1252,7 @@ int Town::ai_settle_new(int raceId)
 
 	//------- it must be within the effective town-to-town distance ---//
 
-	if( m.points_distance( center_x, center_y, xLoc+(STD_TOWN_LOC_WIDTH-1)/2,
+	if( misc.points_distance( center_x, center_y, xLoc+(STD_TOWN_LOC_WIDTH-1)/2,
 		yLoc+(STD_TOWN_LOC_HEIGHT-1)/2 ) > EFFECTIVE_TOWN_TOWN_DISTANCE )
 	{
 		return 0;
@@ -1325,7 +1325,7 @@ int Town::think_attack_nearby_enemy()
 
 					enemyCombatLevel += (int) unitPtr->hit_points;
 
-					if( enemyXLoc == -1 || m.random(5)==0 )
+					if( enemyXLoc == -1 || misc.random(5)==0 )
 					{
 						enemyXLoc = xLoc;
 						enemyYLoc = yLoc;
@@ -1360,7 +1360,7 @@ int Town::think_attack_nearby_enemy()
 							enemyCombatLevel += workerPtr->hit_points;
 					}
 
-					if( enemyXLoc == -1 || m.random(5)==0 )
+					if( enemyXLoc == -1 || misc.random(5)==0 )
 					{
 						enemyXLoc = firmPtr->loc_x1;
 						enemyYLoc = firmPtr->loc_y1;
@@ -1777,15 +1777,15 @@ int Town::think_scout()
 
 	int destX, destY;
 
-	if( m.random(2)==0 )
-		destX = center_x + 50 + m.random(50);
+	if( misc.random(2)==0 )
+		destX = center_x + 50 + misc.random(50);
 	else
-		destX = center_x - 50 - m.random(50);
+		destX = center_x - 50 - misc.random(50);
 
-	if( m.random(2)==0 )
-		destY = center_y + 50 + m.random(50);
+	if( misc.random(2)==0 )
+		destY = center_y + 50 + misc.random(50);
 	else
-		destY = center_y - 50 - m.random(50);
+		destY = center_y - 50 - misc.random(50);
 
 	destX = MAX(0, destX);
 	destX = MIN(MAX_WORLD_X_LOC-1, destX);
