@@ -36,6 +36,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
+#include <ctype.h>
 
 #include <ALL.h>
 #include <OSTR.h>
@@ -89,7 +90,7 @@ void Misc::str_shorten(char* destStr, const char* srcStr, int destLen)
 {
    strncpy( destStr, srcStr, destLen );
 
-   destStr[destLen]=NULL;
+   destStr[destLen]='\0';
 
    //------ no need to cut characters if it fit preciously ----//
    //
@@ -119,9 +120,9 @@ void Misc::str_shorten(char* destStr, const char* srcStr, int destLen)
    int i;
 
    for( i=destLen-1 ; i>0 && destStr[i] != ' ' ; i-- )
-      destStr[i] = NULL;
+      destStr[i] = '\0';
 
-   destStr[i] = NULL;	// trim the space also
+   destStr[i] = '\0';	// trim the space also
 }
 //------------ END OF FUNCTIN Misc::str_shorten -----------------//
 
@@ -147,7 +148,7 @@ int Misc::str_cut(char* dstr, const char* sstr, int schar, int charnum )
    for (si=schar-1,di=0 ; ( di<charnum || forever ) && sstr[si] ; si++,di++)
       dstr[di] = sstr[si] ;
 
-   dstr[di] = NULL;      // terminating NULL sign
+   dstr[di] = '\0';      // terminating NULL sign
 
    return 1;
 }
@@ -332,7 +333,7 @@ void Misc::rtrim( char* des, char* src )
    for ( i=strlen(src)-1 ; src[i]==' ' && i>=0 ; i-- )
       des[i] = src[i];
 
-   des[i+1] = NULL;
+   des[i+1] = '\0';
 }
 //------- END OF FUNCTION Misc::rtrim --------//
 
@@ -354,7 +355,7 @@ void Misc::ltrim( char* des, char* src )
    for ( j=0 ; src[i] ; i++,j++ )
       des[j] = src[i];
 
-   des[j] = NULL;
+   des[j] = '\0';
 }
 //------- END OF FUNCTION Misc::ltrim --------//
 
@@ -376,7 +377,7 @@ void Misc::alltrim( char* des, char* src)
    for ( j=0 ; src[i] && src[i]!=' ' ; i++,j++ )
       des[j] = src[i];
 
-   des[j] = NULL;
+   des[j] = '\0';
 }
 //------- END OF FUNCTION Misc::alltrim --------//
 
@@ -391,7 +392,7 @@ char* Misc::rtrim( char* str )
 
    for ( i=strlen(str)-1 ; str[i]==' ' && i>=0 ; i-- );
 
-   str[i+1] = NULL;
+   str[i+1] = '\0';
 
    return str;
 }
@@ -411,7 +412,7 @@ char* Misc::ltrim( char* str )
    for ( j=0 ; str[i] ; i++,j++ )
       str[j] = str[i];
 
-   str[j] = NULL;
+   str[j] = '\0';
 
    return str;
 }
@@ -431,7 +432,7 @@ char* Misc::alltrim( char* str )
    for ( j=0 ; str[i] && str[i]!=' ' ; i++,j++ )
       str[j] = str[i];
 
-   str[j] = NULL;
+   str[j] = '\0';
 
    return str;
 }
@@ -450,7 +451,7 @@ char* Misc::alltrim( char* str )
 void Misc::empty(char *inStr, int strLen )
 {
    memset( inStr,' ',strLen);
-   inStr[strLen] = NULL;
+   inStr[strLen] = '\0';
 }
 
 //-------- END OF FUNCTION Misc::empty ---------//
@@ -497,7 +498,7 @@ void Misc::fix_str(char* str,int len,char endChar)
 {
    int oldLen;
 
-   if ( endChar == NULL )
+   if ( endChar == '\0' )
       oldLen = strlen(str);
    else
    {
@@ -509,7 +510,7 @@ void Misc::fix_str(char* str,int len,char endChar)
    if ( len > oldLen )
       memset( str+oldLen, ' ', len-oldLen );
 
-   str[len] = NULL;
+   str[len] = '\0';
 }
 
 //--------- END OF FUNCTION Misc::fix_str ---------//
@@ -559,7 +560,7 @@ int Misc::str_cmp( const char* str1, const char* str2 )
       if ( str1[i] != str2[i] )
          return 0;
 
-   return ( str2[i] == NULL && (str1[i]==NULL || str1[i]==' ') );
+   return ( str2[i] == '\0' && (str1[i]=='\0' || str1[i]==' ') );
 }
 
 //--------- END OF FUNCTION Misc::str_cmp -----------//
@@ -587,7 +588,7 @@ int Misc::str_cmpx( const char* str1, const char* str2 )
       if ( str1[i] != str2[i] )
          return 0;
 
-   return ( str2[i] == NULL );
+   return ( str2[i] == '\0' );
 }
 
 //--------- END OF FUNCTION Misc::str_cmpx -----------//
@@ -613,7 +614,7 @@ int Misc::str_icmpx( const char* str1, const char* str2 )
    register int a,b;
 
 
-   for (i=0 ; (a=str1[i]) != NULL && (b=str2[i]) != NULL ; i++)
+   for (i=0 ; (a=str1[i]) != '\0' && (b=str2[i]) != '\0' ; i++)
    {
       if ( a >= 'a' && a <= 'z' )
          a -= 32;
@@ -625,7 +626,7 @@ int Misc::str_icmpx( const char* str1, const char* str2 )
          return 0;
    }
 
-   return ( str2[i] == NULL );
+   return ( str2[i] == '\0' );
 }
 
 //--------- END OF FUNCTION Misc::str_icmpx -----------//
@@ -724,7 +725,7 @@ char* Misc::format( int inNum, int formatType )
    if( sign < 0 )
       *outPtr++ = ')';
 
-   *outPtr++ = NULL;
+   *outPtr++ = '\0';
 
    return outBuf;
 }
@@ -814,7 +815,7 @@ char* Misc::format(double inNum, int formatType)
    if( inNum < 0 )
       *outPtr++ = ')';
 
-   *outPtr++ = NULL;
+   *outPtr++ = '\0';
 
    return outBuf;
 }
@@ -864,13 +865,13 @@ char* Misc::nullify(char* strPtr, int strLen)
    {
       if( str_buf[i] != ' ' )
       {
-         str_buf[i+1] = NULL;
+         str_buf[i+1] = '\0';
          break;
       }
    }
 
    if( i<0 )              // Empty value
-      str_buf[0] = NULL;
+      str_buf[0] = '\0';
 
    return str_buf;
 }
@@ -893,7 +894,7 @@ void Misc::rtrim_fld(char* varPtr, char* fldPtr, int fldLen)
    int rtrimLen = rtrim_len( fldPtr, 1, fldLen );
 
    memcpy( varPtr, fldPtr, rtrimLen );
-   varPtr[rtrimLen] = NULL;
+   varPtr[rtrimLen] = '\0';
 }
 //---------- End of function Misc::rtrim_fld ---------//
 
@@ -1195,6 +1196,12 @@ int misc_mkdir(char *path)
 #ifdef NO_WINDOWS
    return mkdir(path, 0777) == -1 ? errno == EEXIST : 1;
 #else // WINDOWS
+   if (!path[2] && path[1] == ':' && isalpha(path[0]))
+   {
+      // don't try to make a drive letter path
+      // this actually works on windows, but not on Wine
+      return 1;
+   }
    return !CreateDirectory(path, NULL) ?
        GetLastError() == ERROR_ALREADY_EXISTS : 1;
 #endif
@@ -1243,7 +1250,7 @@ int Misc::mkpath(char *abs_path)
 //
 void Misc::change_file_ext(char* desFileName, const char* srcFileName, const char* newExt)
 {
-   int nameLen = m.str_chr(srcFileName, '.');	// include the '.' in the nameLen
+   int nameLen = misc.str_chr(srcFileName, '.');	// include the '.' in the nameLen
 
    err_when( nameLen<1 || nameLen>9 || strlen(newExt)>3 );
 
@@ -1270,7 +1277,7 @@ void Misc::extract_file_name(char* desFileName, const char* srcFileName)
 	}
 
 	strncpy(desFileName, srcFileName+i+1, MAX_PATH);
-	desFileName[MAX_PATH]=NULL;
+	desFileName[MAX_PATH]='\0';
 }
 //---------- End of function Misc::extract_file_name ---------//
 
